/*
 * Licensed to ElasticSearch and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. ElasticSearch licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.action.support.master.info;

import org.elasticsearch.action.support.IgnoreIndices;
import org.elasticsearch.action.support.master.MasterNodeOperationRequest;
import org.elasticsearch.common.Strings;
import org.elasticsearch.common.io.stream.StreamInput;
import org.elasticsearch.common.io.stream.StreamOutput;

import java.io.IOException;

/**
 */
public abstract class ClusterInfoRequest<T extends ClusterInfoRequest> extends MasterNodeOperationRequest<T> {

    private String[] indices = Strings.EMPTY_ARRAY;
    private String[] types = Strings.EMPTY_ARRAY;

    private IgnoreIndices ignoreIndices = IgnoreIndices.NONE;
    private boolean local = false;

    @SuppressWarnings("unchecked")
    public T indices(String... indices) {
        this.indices = indices;
        return (T) this;
    }

    @SuppressWarnings("unchecked")
    public T types(String... types) {
        this.types = types;
        return (T) this;
    }

    @SuppressWarnings("unchecked")
    public T ignoreIndices(IgnoreIndices ignoreIndices) {
        this.ignoreIndices = ignoreIndices;
        return (T) this;
    }

    @SuppressWarnings("unchecked")
    public T local(boolean local) {
        this.local = local;
        return (T) this;
    }

    public String[] indices() {
        return indices;
    }

    public String[] types() {
        return types;
    }

    public IgnoreIndices ignoreIndices() {
        return ignoreIndices;
    }

    public boolean local() {
        return local;
    }

    @Override
    public void readFrom(StreamInput in) throws IOException {
        super.readFrom(in);
        indices = in.readStringArray();
        types = in.readStringArray();
        ignoreIndices = IgnoreIndices.fromId(in.readByte());
        local = in.readBoolean();
    }

    @Override
    public void writeTo(StreamOutput out) throws IOException {
        super.writeTo(out);
        out.writeStringArray(indices);
        out.writeStringArray(types);
        out.writeByte(ignoreIndices.id());
        out.writeBoolean(local);
    }
}
